@@ -1,6 +1,9 @@
 pairwise <- function(treat,
                      event, n, mean, sd, TE, seTE, time,
-                     data = NULL, studlab, ...) {
+                     data = NULL, studlab,
+                     incr = 0.5, allincr = FALSE, addincr = FALSE,
+                     allstudies = FALSE,
+                     ...) {
   
   
   if (is.null(data)) data <- sys.frame(sys.parent())
@@ -78,6 +81,11 @@ pairwise <- function(treat,
       chklist(time)
     else
       meta:::chknumeric(time)
+  ##
+  meta:::chknumeric(incr, min = 0, single = TRUE)
+  meta:::chklogical(allincr)
+  meta:::chklogical(addincr)
+  meta:::chklogical(allstudies)
   
   
   if (!is.null(event) & !is.null(n) &
@@ -266,12 +274,52 @@ pairwise <- function(treat,
   nstud <- length(studlab)
   
   
+  ##
+  ## Auxiliary function to calculate number of arms with zero events
+  ## per study
+  ##
+  sumzero <- function(x) sum(x[!is.na(x)] == 0)
+  
+  
   if (type == "binary") {
     if (length(event) != narms)
       stop("Different length of lists 'treat' and 'event'.")
     if (length(n) != narms)
       stop("Different length of lists 'treat' and 'n'.")
     ##
+    ## Determine increment for individual studies
+    ##
+    n.zeros <- apply(matrix(unlist(event), ncol = length(event)), 1, sumzero)
+    n.all   <- apply(matrix(unlist(n), ncol = length(event)) -
+                     matrix(unlist(event), ncol = length(event)),
+                     1, sumzero)
+    ##
+    incr.study <- rep(0, length(n.zeros))
+    ##
+    if ("sm" %in% nam.args)
+      sm <- args$sm
+    else
+      sm <- gs("smbin")
+    ##
+    sm <- meta:::setchar(sm, c("OR", "RD", "RR", "ASD"))
+    ##
+    sparse <- switch(sm,
+                     OR = (n.zeros > 0) | (n.all > 0),
+                     RD = (n.zeros > 0) | (n.all > 0),
+                     RR = (n.zeros > 0) | (n.all > 0),
+                     ASD = rep(FALSE, length(n.zeros)))
+    ##
+    if (!allincr & !addincr)
+      incr.study[sparse] <- incr
+    else if (addincr)
+      incr.study[] <- incr
+    else {
+      if (any(n.zeros > 0))
+        incr.study[] <- incr
+      else
+        incr.study[] <- 0
+    }
+    ##
     for (i in 1:(narms - 1)) {
       ##
       if (i == 1 & (length(treat[[i]]) != length(event[[i]])))
@@ -292,6 +340,8 @@ pairwise <- function(treat,
                           treat2 = treat[[j]],
                           event1 = event[[i]], n1 = n[[i]],
                           event2 = event[[j]], n2 = n[[j]],
+                          incr = incr.study,
+                          allstudies = allstudies,
                           stringsAsFactors = FALSE)
         ##
         dat <- dat[!(is.na(dat$event1) & is.na(dat$n1)), ]
@@ -299,14 +349,23 @@ pairwise <- function(treat,
         ##
         if (nrow(dat) > 0) {
           m1 <- metabin(dat$event1, dat$n1,
-                        dat$event2, dat$n2, ...)
+                        dat$event2, dat$n2,
+                        incr = dat$incr, addincr = TRUE,
+                        allstudies = allstudies,
+                        ...)
           dat$TE   <- m1$TE
           dat$seTE <- m1$seTE
           ##
-          if (i == 1 & j == 2)
+          dat.NAs <- dat[is.na(dat$TE) | is.na(dat$seTE) | dat$seTE <= 0, ]
+          ##
+          if (i == 1 & j == 2) {
             res <- dat
-          else
+            res.NAs <- dat.NAs
+          }
+          else {
             res <- rbind(res, dat)
+            res.NAs <- rbind(res.NAs, dat.NAs)
+          }
         }
         else
           if (i == 1 & j == 2)
@@ -343,9 +402,17 @@ pairwise <- function(treat,
     ## For standardized mean difference, calculate pooled standard
     ## deviation for multi-arm studies
     ##
-    if ("sm" %in% nam.args && (args$sm == "SMD" & narms > 2)) {
-      pooled.sd <- function(sd, n)
-        sqrt(sum((n - 1) * sd^2) / sum(n - 1))
+    if ("sm" %in% nam.args && (tolower(args$sm) == "smd" & narms > 2)) {
+      pooled.sd <- function(sd, n) {
+        sel <- !is.na(sd) & !is.na(n)
+        ##
+        if (any(sel))
+          res <- sqrt(sum((n[sel] - 1) * sd[sel]^2) / sum(n[sel] - 1))
+        else
+          res <- NA
+        ##
+        res
+      }
       ##
       N <- matrix(unlist(n), ncol = narms, nrow = nstud, byrow = FALSE)
       M <- matrix(unlist(mean), ncol = narms, nrow = nstud, byrow = FALSE)
@@ -366,7 +433,7 @@ pairwise <- function(treat,
       }
       ##
       for (i in seq_len(narms))
-        sd[[i]][sel] <- sd.p
+        sd[[i]][sel] <- ifelse(is.na(sd[[i]][sel]), NA, sd.p)
     }
     ##
     for (i in 1:(narms - 1)) {
@@ -388,10 +455,16 @@ pairwise <- function(treat,
           dat$TE   <- m1$TE
           dat$seTE <- m1$seTE
           ##
-          if (i == 1 & j == 2)
+          dat.NAs <- dat[is.na(dat$TE) | is.na(dat$seTE) | dat$seTE <= 0, ]
+          ##
+          if (i == 1 & j == 2) {
             res <- dat
-          else
+            res.NAs <- dat.NAs
+          }
+          else {
             res <- rbind(res, dat)
+            res.NAs <- rbind(res.NAs, dat.NAs)
+          }
         }
         else
           if (i == 1 & j == 2)
@@ -437,10 +510,16 @@ pairwise <- function(treat,
           dat$TE <- m1$TE
           dat$seTE <- m1$seTE
           ##
-          if (i == 1 & j == 2)
+          dat.NAs <- dat[is.na(dat$TE) | is.na(dat$seTE) | dat$seTE <= 0, ]
+          ##
+          if (i == 1 & j == 2) {
             res <- dat
-          else
+            res.NAs <- dat.NAs
+          }
+          else {
             res <- rbind(res, dat)
+            res.NAs <- rbind(res.NAs, dat.NAs)
+          }
         }
         else
           if (i == 1 & j == 2)
@@ -456,6 +535,25 @@ pairwise <- function(treat,
     if (length(time) != narms)
       stop("Different length of lists 'treat' and 'time'.")
     ##
+    ## Determine increment for individual studies
+    ##
+    n.zeros <- apply(matrix(unlist(event), ncol = length(event)), 1, sumzero)
+    ##
+    incr.study <- rep(0, length(n.zeros))
+    ##
+    sparse <- n.zeros > 0
+    ##
+    if (!allincr & !addincr)
+      incr.study[sparse] <- incr
+    else if (addincr)
+      incr.study[] <- incr
+    else {
+      if (any(n.zeros > 0))
+        incr.study[] <- incr
+      else
+        incr.study[] <- 0
+    }
+    ##
     for (i in 1:(narms - 1)) {
       ##
       if (i == 1 & (length(treat[[i]]) != length(event[[i]])))
@@ -476,20 +574,30 @@ pairwise <- function(treat,
                           treat2 = treat[[j]],
                           event1 = event[[i]], time1 = time[[i]],
                           event2 = event[[j]], time2 = time[[j]],
+                          incr = incr.study,
                           stringsAsFactors = FALSE)
         dat <- dat[!(is.na(dat$event1) & is.na(dat$time1)), ]
         dat <- dat[!(is.na(dat$event2) & is.na(dat$time2)), ]
         ##
         if (nrow(dat) > 0) {
           m1 <- metainc(dat$event1, dat$time1,
-                        dat$event2, dat$time2, ...)
+                        dat$event2, dat$time2,
+                        incr = dat$incr, addincr = TRUE,
+                        allstudies = allstudies,
+                        ...)
           dat$TE <- m1$TE
           dat$seTE <- m1$seTE
           ##
-          if (i == 1 & j == 2)
+          dat.NAs <- dat[is.na(dat$TE) | is.na(dat$seTE) | dat$seTE <= 0, ]
+          ##
+          if (i == 1 & j == 2) {
             res <- dat
-          else
+            res.NAs <- dat.NAs
+          }
+          else {
             res <- rbind(res, dat)
+            res.NAs <- rbind(res.NAs, dat.NAs)
+          }
         }
         else
           if (i == 1 & j == 2)
@@ -522,9 +630,24 @@ pairwise <- function(treat,
                   "(due to single study arm or missing values):\n  ",
                   paste(paste("'", studlab[sel.study], "'", sep = ""),
                         collapse = " - "), sep = ""))
-  
-  
-  
+  ##
+  ## c) Missing treatment estimates or standard errors?
+  ##
+  if (nrow(res.NAs) > 0) {
+    warning("Comparison",
+            if (nrow(res.NAs) > 1) "s",
+            " with missing TE / seTE or zero seTE",
+            " will not be considered in network meta-analysis.",
+            call. = FALSE)
+    cat(paste("Comparison",
+              if (nrow(res.NAs) > 1) "s",
+              " will not be considered in network meta-analysis:\n",
+              sep = ""))
+    ##
+    prmatrix(res.NAs,
+             quote = FALSE, right = TRUE, na.print = "NA",
+             rowlab = rep("", nrow(res.NAs)))
+  }
   
   
   attr(res, "sm") <- m1$sm
